summaryrefslogtreecommitdiffstats
path: root/chrome/browser/resources/net_internals/main.js
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/resources/net_internals/main.js')
-rw-r--r--chrome/browser/resources/net_internals/main.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/resources/net_internals/main.js b/chrome/browser/resources/net_internals/main.js
index 368ebf3..d0428fe 100644
--- a/chrome/browser/resources/net_internals/main.js
+++ b/chrome/browser/resources/net_internals/main.js
@@ -95,8 +95,8 @@ function onLoaded() {
var aNode = document.getElementById(tabIds[i]);
anchorMap[aNode.hash] = tabIds[i];
}
- // Default the empty hash to the requests tab.
- anchorMap['#'] = anchorMap[''] = 'requestsTab';
+ // Default the empty hash to the data tab.
+ anchorMap['#'] = anchorMap[''] = 'dataTab';
window.onhashchange = function() {
var tabId = anchorMap[window.location.hash];